@@ -3,7 +3,7 @@ package Getopt::optparse;
 use strict;
 use Scalar::Util 'reftype';
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
  
 $| = 1;
 
@@ -68,46 +68,47 @@ sub parse_args {
 
     for my $key (keys %{$self->{parser}}) {
         if ($self->{parser}{$key}{'dest'}) {
+            my $parser = $self->{parser}{$key};
             # Handle default value
-            if ($self->{parser}{$key}{default}) {
-                $options{$self->{parser}{$key}{dest}} = $self->{parser}{$key}{default};
+            if ($parser->{default}) {
+                $options{$parser->{dest}} = $parser->{default};
             }
             # Handle count
-            if ($self->{parser}{$key}{action} eq 'count') {
-                $options{$self->{parser}{$key}{dest}} = 0;
+            if ($parser->{action} eq 'count') {
+                $options{$parser->{dest}} = 0;
             }
             # Handle store_true
-            if ($self->{parser}{$key}{action} eq 'store_true') {
+            if ($parser->{action} eq 'store_true') {
                 if ($self->{cmdline} =~ /$key\s+/) {
-                    $options{$self->{parser}{$key}{dest}} = 1;
+                    $options{$parser->{dest}} = 1;
                 } else {
-                    $options{$self->{parser}{$key}{dest}} = 0;
+                    $options{$parser->{dest}} = 0;
                 }
             }
             else {
                 # Populate a default of empty scalar, which will evaluate to false.
-                if (! $self->{parser}{$key}{default}) {
-                    $options{$self->{parser}{$key}{dest}} = '';
+                if (! $parser->{default}) {
+                    $options{$parser->{dest}} = '';
                 }
                 # Populate a default of blank arrayref, which will evaluate to false.
-                if ($self->{parser}{$key}{action} eq 'append') {
-                    $options{$self->{parser}{$key}{dest}} = [];
+                if ($parser->{action} eq 'append') {
+                    $options{$parser->{dest}} = [];
                 }
                 if (my @matches = ($self->{cmdline} =~ /$key\s+/g)) {
                     for my $match (@matches) {
-                        $options{$self->{parser}{$key}{dest}} += 1;
+                        $options{$parser->{dest}} += 1;
                     }
                 }
                 # Search command lien option
                 if (my @matches = ($self->{cmdline} =~ /$key=(.*?)\s+/g)) {
-                    if ($self->{parser}{$key}{action} eq 'append') {
+                    if ($parser->{action} eq 'append') {
                         for my $match (@matches) {
-                            push @{$options{$self->{parser}{$key}{dest}}}, $match;
+                            push @{$options{$parser->{dest}}}, $match;
                         }
                     }
                     else {
                         if ($matches[0] !~ /^-/) {
-                            $options{$self->{parser}{$key}{dest}} = $1;
+                            $options{$parser->{dest}} = $1;
                         }
                     }
                 }
@@ -125,12 +126,20 @@ sub show_help {
     printf("Usage: %s [options]\n\n", $0);
     printf("Options:\n");
 
+    # Determine length for text formatting.
     my %max_length = (1 => 22);
     for my $val ('int_parser', 'parser') {
         for my $key (keys %{$self->{$val}}) {
+            my $special;
+            if ($self->{$val}{$key}{action} eq 'count') {
+                $special = '++';
+            }
+            if ($self->{$val}{$key}{action} eq 'append') {
+                $special = '[]';
+            }
             my $length = length($key);
             if ($self->{$val}{$key}{dest} && ($self->{$val}{$key}{action} ne 'store_true')) {
-                $length += length('=' . $self->{$val}{$key}{dest});
+                $length += length('=' . $self->{$val}{$key}{dest} . $special);
             }
             if ($length > $max_length{1}) {
                 $max_length{1} = $length;
@@ -138,12 +147,22 @@ sub show_help {
         }
     }
 
+    # Print help.
     for my $val ('int_parser', 'parser') {
         for my $key (keys %{$self->{$val}}) {
+            # Add special character for actions count and append.
+            my $special;
+            if ($self->{$val}{$key}{action} eq 'count') {
+                $special = '++';
+            }
+            if ($self->{$val}{$key}{action} eq 'append') {
+                $special = '[]';
+            }
+
             if ($self->{$val}{$key}{dest} && ($self->{$val}{$key}{action} ne 'store_true')) {
                 printf(
                     "%-$max_length{1}s : %s\n",
-                    $key . '=' . uc($self->{$val}{$key}{dest}),
+                    $key . '=' . uc($self->{$val}{$key}{dest}) . $special,
                     $self->{$val}{$key}{help}
                 );
             }
@@ -169,18 +188,19 @@ This library only supports double dash options: --
     $parser->add_option(
         '--hostname', 
         {
-            dest => 'hostname',
-            help => 'Remote hostname',
+            dest    => 'hostname',
+            help    => 'Remote hostname',
             default => 'localhost.localdomain'
         }
     );
     $parser->add_option( 
-        '--global',
-        dest    => 'global',
-        action  => 'store_true',
-        help    => 'Show global',
-        default => 0
-    )
+        '--global', {
+            dest    => 'global',
+            action  => 'store_true',
+            help    => 'Show global',
+            default => 0
+        }
+    );
     $parser->add_option(
         '--username', 
         {
@@ -201,8 +221,12 @@ This library only supports double dash options: --
     my $options = $parser->parse_args();
     printf("Hostname is: %s\n", $options->{hostname});
     printf("Username is: %s\n", $options->{username});
-    if ($options->{global}) {
 
+    if ($options->{global}) {
+    }
+
+    for my $uname (@{$options->{username}}) {
+        print $uname, "\n";
     }
 
 =head1 DESCRIPTION
@@ -226,7 +250,9 @@ The following methods are available:
 
 =over 4
 
-=item Getopt::optparse->add_option()
+=item Getopt::optparse->add_option( 'optionname', {option_attributes} )
+
+Add option to be parsed from command line.  Accepts two arguments.  Both are required:
 
     $parser->add_option(
         '--hostname',
@@ -237,8 +263,6 @@ The following methods are available:
         }
     )
 
-Add option to be parsed from command line.  Accepts two arguments:
-
 =over 4
 
 =item Option Name
@@ -250,7 +274,7 @@ This library uses only double dash.
 
 These may include:
 
-=over 4
+=over 8
 
 =item dest
 
@@ -268,7 +292,7 @@ Text message displayed when --help is found on command line.
 
 The following actions are supported.
 
-=over 4
+=over 8
 
 =item store_true
 
@@ -290,12 +314,16 @@ using this increments dest by one for every occurrence.
 
 =item Getopt::optparse->parse_args()
 
-    my $options = $parser->parse_args();
-    printf("Hostname is: %s\n", $options->{hostname});
-    printf("Username is: %s\n", $options->{username});
-
 Parse added options from command line and return their values as a hash reference.
 
+    my $options = $parser->parse_args();
+
+    printf("Hostname is: %s\n", $options->{hostname});
+
+    for my $uname (@{$options->{username}}) {
+        print $uname, "\n";
+    }
+
 =back
 
 =head1 AUTHOR
